@@ -1,7 +1,6 @@
 use crate::error::Error;
 use util::marshal::{Marshal, MarshalSize, Unmarshal};
 
-use anyhow::Result;
 use bytes::{Buf, BufMut};
 
 /// PacketType specifies the type of an RTCP packet
@@ -17,6 +16,7 @@ pub enum PacketType {
     ApplicationDefined = 204,        // RFC 3550, 6.7 (unimplemented)
     TransportSpecificFeedback = 205, // RFC 4585, 6051
     PayloadSpecificFeedback = 206,   // RFC 4585, 6.3
+    ExtendedReport = 207,            // RFC 3611
 }
 
 impl Default for PacketType {
@@ -52,6 +52,7 @@ impl std::fmt::Display for PacketType {
             PacketType::ApplicationDefined => "APP",
             PacketType::TransportSpecificFeedback => "TSFB",
             PacketType::PayloadSpecificFeedback => "PSFB",
+            PacketType::ExtendedReport => "XR",
         };
         write!(f, "{}", s)
     }
@@ -67,6 +68,7 @@ impl From<u8> for PacketType {
             204 => PacketType::ApplicationDefined,        // RFC 3550, 6.7 (unimplemented)
             205 => PacketType::TransportSpecificFeedback, // RFC 4585, 6051
             206 => PacketType::PayloadSpecificFeedback,   // RFC 4585, 6.3
+            207 => PacketType::ExtendedReport,            // RFC 3611
             _ => PacketType::Unsupported,
         }
     }
@@ -109,7 +111,7 @@ impl MarshalSize for Header {
 }
 
 impl Marshal for Header {
-    fn marshal_to(&self, mut buf: &mut [u8]) -> Result<usize> {
+    fn marshal_to(&self, mut buf: &mut [u8]) -> Result<usize, util::Error> {
         if self.count > 31 {
             return Err(Error::InvalidHeader.into());
         }
@@ -138,7 +140,7 @@ impl Marshal for Header {
 
 impl Unmarshal for Header {
     /// Unmarshal decodes the Header from binary
-    fn unmarshal<B>(raw_packet: &mut B) -> Result<Self>
+    fn unmarshal<B>(raw_packet: &mut B) -> Result<Self, util::Error>
     where
         Self: Sized,
         B: Buf,
@@ -241,12 +243,10 @@ mod test {
 
             if let Some(err) = want_error {
                 let got_err = got.err().unwrap();
-                assert!(
-                    err.equal(&got_err),
+                assert_eq!(
+                    err, got_err,
                     "Unmarshal {}: err = {:?}, want {:?}",
-                    name,
-                    got_err,
-                    err,
+                    name, got_err, err,
                 );
             } else {
                 let actual = got.unwrap();
@@ -308,17 +308,16 @@ mod test {
 
             if let Some(err) = want_error {
                 let got_err = got.err().unwrap();
-                assert!(
-                    err.equal(&got_err),
+                assert_eq!(
+                    err, got_err,
                     "Unmarshal {} rr: err = {:?}, want {:?}",
-                    name,
-                    got_err,
-                    err,
+                    name, got_err, err,
                 );
             } else {
                 let data = got.ok().unwrap();
                 let buf = &mut data.clone();
-                let actual = Header::unmarshal(buf).expect(format!("Unmarshal {}", name).as_str());
+                let actual =
+                    Header::unmarshal(buf).unwrap_or_else(|_| panic!("Unmarshal {}", name));
 
                 assert_eq!(
                     actual, want,
