@@ -4,11 +4,12 @@ mod transport_layer_cc_test;
 use crate::{error::Error, header::*, packet::*, util::*};
 use util::marshal::{Marshal, MarshalSize, Unmarshal};
 
-use anyhow::Result;
 use bytes::{Buf, BufMut};
 use std::any::Any;
 use std::fmt;
 
+type Result<T> = std::result::Result<T, util::Error>;
+
 /// https://tools.ietf.org/html/draft-holmer-rmcat-transport-wide-cc-extensions-01#page-5
 /// 0                   1                   2                   3
 /// 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
@@ -427,7 +428,7 @@ const PACKET_CHUNK_OFFSET: usize = 16;
 const TYPE_TCC_STATUS_VECTOR_CHUNK: usize = 1;
 
 /// https://tools.ietf.org/html/draft-holmer-rmcat-transport-wide-cc-extensions-01#section-3.1.5
-const TYPE_TCC_DELTA_SCALE_FACTOR: i64 = 250;
+pub const TYPE_TCC_DELTA_SCALE_FACTOR: i64 = 250;
 
 // Notice: RFC is wrong: "packet received" (0) and "packet not received" (1)
 // if S == TYPE_TCCSYMBOL_SIZE_ONE_BIT, symbol list will be: TypeTCCPacketNotReceived TypeTCCPacketReceivedSmallDelta
@@ -498,20 +499,10 @@ impl Packet for TransportLayerCc {
     fn raw_size(&self) -> usize {
         let mut n = HEADER_LENGTH + PACKET_CHUNK_OFFSET + self.packet_chunks.len() * 2;
         for d in &self.recv_deltas {
-            let delta = d.delta / TYPE_TCC_DELTA_SCALE_FACTOR;
-
             // small delta
-            if d.type_tcc_packet == SymbolTypeTcc::PacketReceivedSmallDelta
-                && delta >= 0
-                && delta <= u8::MAX as i64
-            {
+            if d.type_tcc_packet == SymbolTypeTcc::PacketReceivedSmallDelta {
                 n += 1;
-            }
-
-            if d.type_tcc_packet == SymbolTypeTcc::PacketReceivedLargeDelta
-                && delta >= i16::MIN as i64
-                && delta <= i16::MAX as i64
-            {
+            } else {
                 n += 2
             }
         }
